@@ -1,6 +1,5 @@
-from sqlite3 import DatabaseError
 import unittest
-from imdb_lib import httpIMDB
+from session import httpIMDB
 from unittest import TestCase
 import pandas as pd
 
@@ -12,9 +11,10 @@ class TestClass(TestCase):
         self.Id = 'tt0993846'
 
     def tearDown(self) -> None:
-        self.assertIsNotNone(self.df)
+        # self.assertIsNotNone(self.df)
         self.assertFalse(self.df.empty)
         self.assertFalse(self.df.isnull().values.any())
+        self.assertEqual(sum(self.df.isna().sum().to_list()), 0)
         self.session.close_session()
         self.assertIsNotNone(self.Id)
 
@@ -37,13 +37,27 @@ class TestClass(TestCase):
 
 
     def test_getTopRatedMovies(self):
-        self.df = self.session.getTopRatedMovies()
-
-        self.assertEqual(len(self.df), 250)
-
+        self.df = self.session.getTopRatedMovies()    
+  
 
     def test_getTitleDetails(self):
         self.df = self.session.getTitleDetails(self.Id)
+        
+        cols = self.df.columns.to_list()
+        self.assertEqual(cols, 10)
+
+        # assert all columns exist
+        cols = len(self.df.columns.to_list())
+        self.assertEqual(cols, 10)
+        
+        # assert duration is a tuple with length == 2
+        duration = self.df.duration.to_list()
+        bool_d = [True if len(d) == 2 else False for d in duration]
+        self.assertNotIn(False, bool_d)
+        
+        # assert vals of duration arent NaN or simillar
+        for v1,v2 in duration:
+            self.assertIsNotNone(v1+v2)
 
 
     def test_searchTitle(self):
